#!/usr/bin/env python
def add(a=0,b=0):
    if a:
        if b:
            try:
                c=a+b
            except ValueError:
                print("You can't write!")
            else:
                return c
        else:
            print('You did not enter "b"!')
    else:
        print('You did not enter "a"!')
def reduce(a=0,b=0):
    if a:
        if b:
            try:
                c=a-b
            except ValueError:
                print("You can't write!")
            else:
                return c
        else:
            print('You did not enter "b"!')
    else:
        print('You did not enter "a"!')
def ride(a=0,b=0):
    if a:
        if b:
            try:
                c=a*b
            except ValueError:
                print("You can't write!")
            else:
                return c
        else:
            print('You did not enter "b"!')
    else:
        print('You did not enter "a"!')
def division(a=0,b=0):
    if a:
        if b:
            try:
                c=a/b
            except ValueError:
                print("You can't write!")
            else:
                try:
                    c=a/b
                except ZeroDivisionError:
                    print("You can't division by zero!")
                else:
                    return c
        else:
            print('You did not enter "b"!')
    else:
        print('You did not enter "a"!')
def square(a=0,b=0):
    if a:
        if b:
            try:
                c=a**b
            except ValueError:
                print("You can't write!")
            else:
                return c
        else:
            print('You did not enter "b"!')
    else:
        print('You did not enter "a"!')
def square_two(a=0):
    if a:
        try:
            c=a**2
        except ValueError:
            print("You can't write!")
        else:
            return c
    else:
        print('You did not enter "a"!')
def square_root(a=0):
    if a:
        try:
            c=a**(1/2)
        except ValueError:
            print("You can't write!")
        else:
            return c
    else:
        print('You did not enter "a"!')
